/**
 * Digital clock showing times between 00:00 and 23.59 as a string.
 * 
 * @author Daniel
 * 2011-04-16
 */
public class Clock {
	
	private NumberDisplay hours;
	private NumberDisplay minutes;
	private String displayString;
	
	/**
	 * Creates a new clock set to 00:00 by calling the constructor with parameters.
	 */
	public Clock() {
	    this(0,0);
	}
	
	/**
	 * Creates a new clock set to hour:minute.
	 * @param hour
	 * @param minute
	 */
	public Clock(int hour, int minute){
		super();
		this.hours=new NumberDisplay(0,24);
		this.minutes=new NumberDisplay(0,60);
		this.setTime(hour,minute);
		this.updateDisplay();
	}
	
	/**
	 * Increases the time of the clock with one minute.
	 */
	public void timeTick(){		
		minutes.increment();		
		if(minutes.didWrapAround()){ // Increases hours if minutes wraps around to 0.
			hours.increment();
		}
		this.updateDisplay();
	}
	
	/**
	 * Sets the clock to a new time.
	 * @param hour
	 * @param minute
	 */
	public void setTime(int hour,int minute){
		minutes.setValue(minute);
		hours.setValue(hour);		
		this.updateDisplay();
	}
	
	/**
	 * Gets time.
	 * @return display as a string
	 */
	public String getTime(){
		return this.displayString;
	}
	
	/**
	 * Updates the string containing the display.
	 */
	private void updateDisplay(){
		this.displayString=hours.getDisplayValue()+":"+minutes.getDisplayValue();
	}
	
	/**
	 * Gets hours.
	 * @return hours as int
	 */
	public int getHour(){
		return hours.getValue();
	}
	
	/**
	 * Gets minutes.
	 * @return minutes as int
	 */
	public int getMinute(){
		return minutes.getValue();
	}
}
